package com.tutorialesprogramacionya.compose21

import android.app.Activity
import android.content.Intent
import android.net.Uri
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil.compose.rememberImagePainter
import com.android.volley.Request
import com.android.volley.toolbox.JsonObjectRequest
import com.android.volley.toolbox.Volley


class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        ListadoVideos(this)
        setContent {
            PantallaPrincipal()
        }
    }
}

data class Video(val id: String, val titulo: String, val canal: String)

val videos = mutableStateListOf<Video>()

fun ListadoVideos(activity: Activity) {
    val url = "https://api.dailymotion.com/videos?limit=100"
    val requestQueue = Volley.newRequestQueue(activity)
    val jsonObjectRequest = JsonObjectRequest(
        Request.Method.GET,
        url,
        null,
        { response ->
            val jsonArray = response.getJSONArray("list")
            videos.clear()
            for (i in 0 until jsonArray.length()) {
                val registro = jsonArray.getJSONObject(i)
                val id = registro.getString("id")
                val titulo = registro.getString("title")
                val canal = registro.getString("channel")
                videos.add(Video(id, titulo, canal))
            }
        },
        { error ->
        }
    )
    requestQueue.add(jsonObjectRequest)
}

@Composable
fun PantallaPrincipal() {
    val activity = LocalContext.current
    LazyColumn() {
        items(videos) { video ->
            Card(
                elevation = 5.dp,
                modifier = Modifier
                    .padding(10.dp)
                    .fillMaxWidth()
                    .clickable {
                        val intento = Intent(
                            Intent.ACTION_VIEW,
                            Uri.parse("https://www.dailymotion.com/video/${video.id}")
                        )
                        activity.startActivity(intento)
                    }
            ) {
                Column() {
                    Text(
                        text = "Título: ${video.titulo}",
                        fontSize = 18.sp,
                        modifier = Modifier.padding(start = 10.dp, end = 10.dp, bottom = 5.dp)
                    )
                    Text(
                        text = "Canal:${video.canal}",
                        modifier = Modifier.padding(10.dp)
                    )
                    Image(
                        painter = rememberImagePainter("https://www.dailymotion.com/thumbnail/video/${video.id}"),
                        contentDescription = null,
                        modifier = Modifier.size(350.dp, 200.dp)
                    )
                }
            }
        }
    }
}